// klinfo.cc
//
// Author: allauzen@cs.nyu.edu (Cyril Allauzen)
//
// \file
// Prints out various information about a kernel.

#include "kernel/lib/kernel.h"

using namespace kernel;

int main(int argc, char** argv) {
  string usage = "Print some information about the kernel.\n\n  Usage: ";
  usage += argv[0];
  usage += " kernel.kl\n";

  std::set_new_handler(FailedNewHandler);
  SetFlags(usage.c_str(), &argc, &argv, true);
  if (argc > 2) {
    ShowUsage();
    return 1;
  }
  string in = argc > 1 ? string(argv[1]) : string();

  KernelBase *kernel = KernelBase::Read(in);
  if(!kernel)
    LOG(FATAL) << "klinfo: failed to read " << in;


  cout << "kernel type\t\t\t" << kernel->Type() << endl;
  cout << "object type\t\t\t" << kernel->ObjectType() << endl;
  cout << "dataset present\t\t\t";
  if (!kernel->Data())
    cout << "no" << endl;
  else
    cout << "yes" << endl
         << "dataset file\t\t\t" << kernel->Data()->File() << endl
         << "dataset size\t\t\t" << kernel->Data()->Size() << endl;


  uint64 props = kernel->Properties();
  cout << "symmetric\t\t\t"
       << (props & kSymmetric ? "yes"
           : (props & kAsymmetric ? "no" : "unknown")) << endl;
  cout << "definite\t\t\t"
       << (props & kPosDefinite ? "positive"
           : (props & kNegDefinite ? "negative"
              : (props & kNotDefinite ? "no" : "unknown"))) << endl;
  cout << "normalized\t\t\t"
       << (props & kNormalized ? "yes"
           : (props & kUnnormalized ? "no" : "unknown")) << endl;


  delete kernel;
  return 0;
}
