// klmismatch.cc
//
// Author: allauzen@cs.nyu.edu (Cyril Allauzen)
//
// \file
// Generate a mismatch counting fst

//#include <fst/fstlib.h>
#include "kernel/lib/mismatch-fst.h"

DEFINE_int32(k, -1, "k, subsequence of lenght k");
DEFINE_int32(m, -1, "m, at most m mismatches");
DEFINE_int32(sigma, -1, "alphabet size (i.e. max label)");

using namespace kernel;
using namespace fst;

typedef VectorFst<LogArc> LogVectorFst;

int main(int argc, char** argv) {
  string usage = "Generate a (k,m)-mismatch counting transducer (k > m)";
  usage += ".\n\n  Usage: ";
  usage += argv[0];
  usage += " > out.fst \n";

  std::set_new_handler(FailedNewHandler);
  SetFlags(usage.c_str(), &argc, &argv, true);
  if (argc != 1) {
    ShowUsage();
    return 1;
  }

  if ((FLAGS_k == -1) || (FLAGS_m == -1))
    LOG(FATAL) << "klmismatchfst: k and m values need to be specified \n";
  if (FLAGS_sigma == -1)
    LOG(FATAL) << "klmismatchfst: value of larger symbol need to be specified"
         << " with --sigma=n\n";

  LogVectorFst fst;
  Mismatch(&fst, FLAGS_k, FLAGS_m, FLAGS_sigma);
  ArcSort(&fst, ILabelCompare<LogArc>());
  fst.Write(string());
}
